{% extends 'base.html' %}
{% load django_bootstrap5 i18n %}

{% block content %}

{% if validlink %}

<h1>{% translate "New password" %}</h1>

{% include 'ndh/form.html' %}

{% else %}

<h1>{% translate "Failure" %}</h1>

<p>{% translate "This link is invalid, probably because it has already been used. Try again !" %}</p>

{% endif %}

{% endblock %}
