{% load django_bootstrap5 i18n %}

<form method="post" action="" class="form-horizontal" role="form">
  {% csrf_token %}
  {% bootstrap_formset form layout="horizontal" %}
  <div class="d-flex align-items-center my-3">
    {% bootstrap_button _("Confirm") button_class="btn-success" button_type="submit" extra_classes="w-25 mx-auto py-3" %}
    {% bootstrap_button _("Cancel") button_class="btn-danger" href="javascript:history.back()" extra_classes="w-25 mx-auto py-3" %}
  </div>
</form>
