{% extends 'base.html' %}
{% load i18n %}

{% block content %}
{% include 'ndh/form.html' %}
<hr>
<p class="text-center">
<a class="btn btn-warning" href="{% url 'password_reset' %}">{% translate "Reset Password" %}</a>
</p>
{% endblock %}
